@@ -41,6 +41,7 @@
 #	include <io.h>
 #	include <sys/timeb.h>
 #else
+#	include <pwd.h>
 #	include <sys/types.h>
 #	include <sys/time.h>
 #	include <termios.h>
@@ -166,7 +167,48 @@ logOpen(const auctionInfo *aip, const char *logdir)
 	if (logdir) {
 		char *tmp = logfilename;
 
+/* not win32 --> *nix */
+#if defined(WIN32)
 		logfilename = myStrdup3(logdir, "/", logfilename);
+#else
+		/*
+		 * Usually the logdir on *nix looks something like this: ~/esniper/logs
+		 * we want it to look (typically) like this: /home/user/esniper/logs/
+		 * (depends on environment HOME variable).
+		 *
+		 * Need to distinguish between * ~/ (i.e. $HOME) and
+		 * ~foo/ (i.e. foo's home directory in /etc/passwd).
+		 */
+		if (logdir[0] == '~') {
+			if (logdir[1] == '\0') {
+				logfilename = myStrdup3(getenv("HOME"), "/", logfilename);
+			} else if (logdir[1] == '/') {
+				logfilename = myStrdup4(getenv("HOME"), logdir+1, "/", logfilename);
+			} else {
+				const char *slash = strchr(logdir, '/');
+				struct passwd *pw;
+
+				if (slash) {
+					size_t namelen = (size_t)(slash - (logdir+1));
+					char *username = myMalloc(namelen + 1);
+
+					strncpy(username, logdir + 1, namelen);
+					username[namelen] = '\0';
+					pw = getpwnam(username);
+					free(username);
+				} else {
+					slash = logdir + strlen(logdir);
+					pw = getpwnam(logdir + 1);
+				}
+
+				if (pw)
+					logfilename = myStrdup4(pw->pw_dir, slash, "/", logfilename);
+				else
+					logfilename = myStrdup3(logdir, "/", logfilename);
+			}
+		} else
+			logfilename = myStrdup3(logdir, "/", logfilename);
+#endif
 		free(tmp);
 	}
 	logClose();
@@ -280,11 +322,12 @@ checkVersion(void)
  * Request user to file a bug report.
  */
 void
-bugReport(const char *func, const char *file, int line, auctionInfo *aip, memBuf_t *mp, const char *fmt, ...)
+bugReport(const char *func, const char *file, int line, auctionInfo *aip, memBuf_t *mp, const optionTable_t *optiontab, const char *fmt, ...)
 {
 	va_list arglist;
 	const char *version = getVersion();
 	const char *newVersion = checkVersion();
+	char *optionlog;
 
 	if (newVersion) {
 		printLog(stdout,
@@ -333,6 +376,11 @@ bugReport(const char *func, const char *file, int line, auctionInfo *aip, memBuf
 			freePageInfo(pp);
 		}
 	}
+	if(optiontab) {
+		optionlog = logOptionValues(optiontab);
+		printLog(stdout, "%s", optionlog);
+		free(optionlog);
+	}
 	printf("\t");
 	if (options.debug && logfile) {
 		va_start(arglist, fmt);
@@ -358,6 +406,8 @@ bugReport(const char *func, const char *file, int line, auctionInfo *aip, memBuf
 		} else
 			printLog(stdout, "\tFailed to create bug file %s: %s\n", bugname, strerror(errno));
 		free(bugname);
+	} else {
+		printLog(stdout, "\tPage content not available.");
 	}
 	printLog(stdout, "and click submit.\n");
 	fflush(stdout);
@@ -414,6 +464,15 @@ nullStr(const char *s)
 	return s ? s : "(null)";
 }
 
+/*
+ * Return a valid string, even if it is null
+ */
+const char *
+nullEmptyStr(const char *s)
+{
+	return s ? s : "";
+}
+
 /*
  * Current date/time
  */
@@ -479,9 +538,19 @@ prompt(const char *p, int noecho)
 		tmp = save & (~ENABLE_ECHO_INPUT);
 		SetConsoleMode(in, tmp);
 #else
+		/*
+		 * echo=ECHO is a silly hack to work around poorly defined constant
+		 * that trips up a poorly implemented warning.  tcflag_t is unsigned,
+		 * ECHO is signed.  gcc warns if you mix signed and unsigned in an
+		 * expression, but does not warn if you mix in an assignment with a
+		 * constant (assuming constant fits in the type of the variable).
+		 */
+		tcflag_t echo = ECHO;
+
 		tcgetattr(fileno(stdin), &save);
 		memcpy(&tmp, &save, sizeof(struct termios));
-		tmp.c_lflag &= (~ECHO);
+		/* you'll get the warning here if you change ~echo to ~ECHO */
+		tmp.c_lflag &= ~echo;
 		tcsetattr(fileno(stdin), TCSANOW, &tmp);
 #endif
 	}
@@ -543,7 +612,7 @@ boolValue(const char *value)
 char *
 priceFixup(char *price, auctionInfo *aip)
 {
-	int len, i, j, start = 0, end, count = 0;
+	size_t len, i, j, start = 0, end, count = 0;
 
 	if (!price)
 		return price;
@@ -635,12 +704,12 @@ setUsername(char *username)
 void
 setPassword(char *password)
 {
-	int i, len;
+	size_t i, len;
 	char *escapedPassword;
 
 	/* http escape password, clear original */
 	len = strlen(password);
-	escapedPassword = curl_escape(password, len);
+	escapedPassword = curl_escape(password, (int)len);
 	for (i = 0; i < len; ++i)
 		password[i] = '\0';
 	free(password);
